@@ -15,14 +15,13 @@ class DataFrameAttributes:
         self.cur_index = self.df.index
 
     def time_get_index(self):
-        self.foo = self.df.index
+        self.df.index
 
     def time_set_index(self):
         self.df.index = self.cur_index
 
 
 class SeriesArrayAttribute:
-
     params = [["numeric", "object", "category", "datetime64", "datetime64tz"]]
     param_names = ["dtype"]
 
