@@ -2,15 +2,16 @@ import numpy as np
 
 import pandas as pd
 from pandas import (
+    NA,
+    Categorical,
     DataFrame,
+    Float64Dtype,
     MultiIndex,
     Series,
     Timestamp,
     date_range,
 )
 
-from .pandas_vb_common import tm
-
 try:
     from pandas.tseries.offsets import (
         Hour,
@@ -18,19 +19,25 @@ try:
     )
 except ImportError:
     # For compatibility with older versions
-    from pandas.core.datetools import *  # noqa
+    from pandas.core.datetools import (
+        Hour,
+        Nano,
+    )
 
 
 class FromDicts:
     def setup(self):
         N, K = 5000, 50
-        self.index = tm.makeStringIndex(N)
-        self.columns = tm.makeStringIndex(K)
+        self.index = pd.Index([f"i-{i}" for i in range(N)], dtype=object)
+        self.columns = pd.Index([f"i-{i}" for i in range(K)], dtype=object)
         frame = DataFrame(np.random.randn(N, K), index=self.index, columns=self.columns)
         self.data = frame.to_dict()
         self.dict_list = frame.to_dict(orient="records")
         self.data2 = {i: {j: float(j) for j in range(100)} for i in range(2000)}
 
+        # arrays which we won't consolidate
+        self.dict_of_categoricals = {i: Categorical(np.arange(N)) for i in range(K)}
+
     def time_list_of_dict(self):
         DataFrame(self.dict_list)
 
@@ -50,6 +57,10 @@ class FromDicts:
         # nested dict, integer indexes, regression described in #621
         DataFrame(self.data2)
 
+    def time_dict_of_categoricals(self):
+        # dict of arrays that we won't consolidate
+        DataFrame(self.dict_of_categoricals)
+
 
 class FromSeries:
     def setup(self):
@@ -61,12 +72,11 @@ class FromSeries:
 
 
 class FromDictwithTimestamp:
-
     params = [Nano(1), Hour(1)]
     param_names = ["offset"]
 
     def setup(self, offset):
-        N = 10 ** 3
+        N = 10**3
         idx = date_range(Timestamp("1/1/1900"), freq=offset, periods=N)
         df = DataFrame(np.random.randn(N, 10), index=idx)
         self.d = df.to_dict()
@@ -76,7 +86,6 @@ class FromDictwithTimestamp:
 
 
 class FromRecords:
-
     params = [None, 1000]
     param_names = ["nrows"]
 
@@ -103,7 +112,6 @@ class FromNDArray:
 
 
 class FromLists:
-
     goal_time = 0.2
 
     def setup(self):
@@ -116,7 +124,6 @@ class FromLists:
 
 
 class FromRange:
-
     goal_time = 0.2
 
     def setup(self):
@@ -127,8 +134,28 @@ class FromRange:
         self.df = DataFrame(self.data)
 
 
-class FromArrays:
+class FromScalar:
+    def setup(self):
+        self.nrows = 100_000
 
+    def time_frame_from_scalar_ea_float64(self):
+        DataFrame(
+            1.0,
+            index=range(self.nrows),
+            columns=list("abc"),
+            dtype=Float64Dtype(),
+        )
+
+    def time_frame_from_scalar_ea_float64_na(self):
+        DataFrame(
+            NA,
+            index=range(self.nrows),
+            columns=list("abc"),
+            dtype=Float64Dtype(),
+        )
+
+
+class FromArrays:
     goal_time = 0.2
 
     def setup(self):
