@@ -5,6 +5,7 @@ import numpy as np
 
 from pandas import (
     DataFrame,
+    Index,
     MultiIndex,
     NaT,
     Series,
@@ -14,7 +15,54 @@ from pandas import (
     timedelta_range,
 )
 
-from .pandas_vb_common import tm
+
+class AsType:
+    params = [
+        [
+            # from_dtype == to_dtype
+            ("Float64", "Float64"),
+            ("float64[pyarrow]", "float64[pyarrow]"),
+            # from non-EA to EA
+            ("float64", "Float64"),
+            ("float64", "float64[pyarrow]"),
+            # from EA to non-EA
+            ("Float64", "float64"),
+            ("float64[pyarrow]", "float64"),
+            # from EA to EA
+            ("Int64", "Float64"),
+            ("int64[pyarrow]", "float64[pyarrow]"),
+        ],
+        [False, True],
+    ]
+    param_names = ["from_to_dtypes", "copy"]
+
+    def setup(self, from_to_dtypes, copy):
+        from_dtype = from_to_dtypes[0]
+        if from_dtype in ("float64", "Float64", "float64[pyarrow]"):
+            data = np.random.randn(100, 100)
+        elif from_dtype in ("int64", "Int64", "int64[pyarrow]"):
+            data = np.random.randint(0, 1000, (100, 100))
+        else:
+            raise NotImplementedError
+        self.df = DataFrame(data, dtype=from_dtype)
+
+    def time_astype(self, from_to_dtypes, copy):
+        self.df.astype(from_to_dtypes[1], copy=copy)
+
+
+class Clip:
+    params = [
+        ["float64", "Float64", "float64[pyarrow]"],
+    ]
+    param_names = ["dtype"]
+
+    def setup(self, dtype):
+        data = np.random.randn(100_000, 10)
+        df = DataFrame(data, dtype=dtype)
+        self.df = df
+
+    def time_clip(self, dtype):
+        self.df.clip(-1.0, 1.0)
 
 
 class GetNumericData:
@@ -28,26 +76,6 @@ class GetNumericData:
         self.df._get_numeric_data()
 
 
-class Lookup:
-    def setup(self):
-        self.df = DataFrame(np.random.randn(10000, 8), columns=list("abcdefgh"))
-        self.df["foo"] = "bar"
-        self.row_labels = list(self.df.index[::10])[:900]
-        self.col_labels = list(self.df.columns) * 100
-        self.row_labels_all = np.array(
-            list(self.df.index) * len(self.df.columns), dtype="object"
-        )
-        self.col_labels_all = np.array(
-            list(self.df.columns) * len(self.df.index), dtype="object"
-        )
-
-    def time_frame_fancy_lookup(self):
-        self.df.lookup(self.row_labels, self.col_labels)
-
-    def time_frame_fancy_lookup_all(self):
-        self.df.lookup(self.row_labels_all, self.col_labels_all)
-
-
 class Reindex:
     def setup(self):
         N = 10**3
@@ -391,10 +419,8 @@ class Isnull:
 
 
 class Fillna:
-
     params = (
         [True, False],
-        ["pad", "bfill"],
         [
             "float64",
             "float32",
@@ -406,15 +432,15 @@ class Fillna:
             "timedelta64[ns]",
         ],
     )
-    param_names = ["inplace", "method", "dtype"]
+    param_names = ["inplace", "dtype"]
 
-    def setup(self, inplace, method, dtype):
+    def setup(self, inplace, dtype):
         N, M = 10000, 100
         if dtype in ("datetime64[ns]", "datetime64[ns, tz]", "timedelta64[ns]"):
             data = {
-                "datetime64[ns]": date_range("2011-01-01", freq="H", periods=N),
+                "datetime64[ns]": date_range("2011-01-01", freq="h", periods=N),
                 "datetime64[ns, tz]": date_range(
-                    "2011-01-01", freq="H", periods=N, tz="Asia/Tokyo"
+                    "2011-01-01", freq="h", periods=N, tz="Asia/Tokyo"
                 ),
                 "timedelta64[ns]": timedelta_range(start="1 day", periods=N, freq="1D"),
             }
@@ -426,13 +452,19 @@ class Fillna:
             if dtype == "Int64":
                 values = values.round()
             self.df = DataFrame(values, dtype=dtype)
+        self.fill_values = self.df.iloc[self.df.first_valid_index()].to_dict()
 
-    def time_frame_fillna(self, inplace, method, dtype):
-        self.df.fillna(inplace=inplace, method=method)
+    def time_fillna(self, inplace, dtype):
+        self.df.fillna(value=self.fill_values, inplace=inplace)
+
+    def time_ffill(self, inplace, dtype):
+        self.df.ffill(inplace=inplace)
+
+    def time_bfill(self, inplace, dtype):
+        self.df.bfill(inplace=inplace)
 
 
 class Dropna:
-
     params = (["all", "any"], [0, 1])
     param_names = ["how", "axis"]
 
@@ -451,8 +483,23 @@ class Dropna:
         self.df_mixed.dropna(how=how, axis=axis)
 
 
-class Count:
+class Isna:
+    params = ["float64", "Float64", "float64[pyarrow]"]
+    param_names = ["dtype"]
 
+    def setup(self, dtype):
+        data = np.random.randn(10000, 1000)
+        # all-na columns
+        data[:, 600:800] = np.nan
+        # partial-na columns
+        data[800:1000, 4000:5000] = np.nan
+        self.df = DataFrame(data, dtype=dtype)
+
+    def time_isna(self, dtype):
+        self.df.isna()
+
+
+class Count:
     params = [0, 1]
     param_names = ["axis"]
 
@@ -464,20 +511,11 @@ class Count:
         self.df_mixed = self.df.copy()
         self.df_mixed["foo"] = "bar"
 
-        self.df.index = MultiIndex.from_arrays([self.df.index, self.df.index])
-        self.df.columns = MultiIndex.from_arrays([self.df.columns, self.df.columns])
-        self.df_mixed.index = MultiIndex.from_arrays(
-            [self.df_mixed.index, self.df_mixed.index]
-        )
-        self.df_mixed.columns = MultiIndex.from_arrays(
-            [self.df_mixed.columns, self.df_mixed.columns]
-        )
+    def time_count(self, axis):
+        self.df.count(axis=axis)
 
-    def time_count_level_multi(self, axis):
-        self.df.count(axis=axis, level=1)
-
-    def time_count_level_mixed_dtypes_multi(self, axis):
-        self.df_mixed.count(axis=axis, level=1)
+    def time_count_mixed_dtypes(self, axis):
+        self.df_mixed.count(axis=axis)
 
 
 class Apply:
@@ -497,8 +535,8 @@ class Apply:
     def time_apply_lambda_mean(self):
         self.df.apply(lambda x: x.mean())
 
-    def time_apply_np_mean(self):
-        self.df.apply(np.mean)
+    def time_apply_str_mean(self):
+        self.df.apply("mean")
 
     def time_apply_pass_thru(self):
         self.df.apply(lambda x: x)
@@ -551,11 +589,7 @@ class Equals:
 
 
 class Interpolate:
-
-    params = [None, "infer"]
-    param_names = ["downcast"]
-
-    def setup(self, downcast):
+    def setup(self):
         N = 10000
         # this is the worst case, where every column has NaNs.
         arr = np.random.randn(N, 100)
@@ -576,11 +610,11 @@ class Interpolate:
         self.df2.loc[1::5, "A"] = np.nan
         self.df2.loc[1::5, "C"] = np.nan
 
-    def time_interpolate(self, downcast):
-        self.df.interpolate(downcast=downcast)
+    def time_interpolate(self):
+        self.df.interpolate()
 
-    def time_interpolate_some_good(self, downcast):
-        self.df2.interpolate(downcast=downcast)
+    def time_interpolate_some_good(self):
+        self.df2.interpolate()
 
 
 class Shift:
@@ -605,7 +639,8 @@ class Nunique:
 
 class SeriesNuniqueWithNan:
     def setup(self):
-        self.ser = Series(100000 * (100 * [np.nan] + list(range(100)))).astype(float)
+        values = 100 * [np.nan] + list(range(100))
+        self.ser = Series(np.tile(values, 10000), dtype=float)
 
     def time_series_nunique_nan(self):
         self.ser.nunique()
@@ -614,7 +649,7 @@ class SeriesNuniqueWithNan:
 class Duplicated:
     def setup(self):
         n = 1 << 20
-        t = date_range("2015-01-01", freq="S", periods=(n // 64))
+        t = date_range("2015-01-01", freq="s", periods=(n // 64))
         xs = np.random.randn(n // 64).round(2)
         self.df = DataFrame(
             {
@@ -636,7 +671,6 @@ class Duplicated:
 
 
 class XS:
-
     params = [0, 1]
     param_names = ["axis"]
 
@@ -649,7 +683,6 @@ class XS:
 
 
 class SortValues:
-
     params = [True, False]
     param_names = ["ascending"]
 
@@ -660,24 +693,37 @@ class SortValues:
         self.df.sort_values(by="A", ascending=ascending)
 
 
-class SortIndexByColumns:
-    def setup(self):
+class SortMultiKey:
+    params = [True, False]
+    param_names = ["monotonic"]
+
+    def setup(self, monotonic):
         N = 10000
         K = 10
-        self.df = DataFrame(
+        df = DataFrame(
             {
-                "key1": tm.makeStringIndex(N).values.repeat(K),
-                "key2": tm.makeStringIndex(N).values.repeat(K),
+                "key1": Index([f"i-{i}" for i in range(N)], dtype=object).values.repeat(
+                    K
+                ),
+                "key2": Index([f"i-{i}" for i in range(N)], dtype=object).values.repeat(
+                    K
+                ),
                 "value": np.random.randn(N * K),
             }
         )
+        if monotonic:
+            df = df.sort_values(["key1", "key2"])
+        self.df_by_columns = df
+        self.df_by_index = df.set_index(["key1", "key2"])
 
-    def time_frame_sort_values_by_columns(self):
-        self.df.sort_values(by=["key1", "key2"])
+    def time_sort_values(self, monotonic):
+        self.df_by_columns.sort_values(by=["key1", "key2"])
+
+    def time_sort_index(self, monotonic):
+        self.df_by_index.sort_index()
 
 
 class Quantile:
-
     params = [0, 1]
     param_names = ["axis"]
 
@@ -717,7 +763,6 @@ class GetDtypeCounts:
 
 
 class NSort:
-
     params = ["first", "last", "all"]
     param_names = ["keep"]
 
@@ -767,4 +812,62 @@ class MemoryUsage:
         self.df2.memory_usage(deep=True)
 
 
+class Round:
+    def setup(self):
+        self.df = DataFrame(np.random.randn(10000, 10))
+        self.df_t = self.df.transpose(copy=True)
+
+    def time_round(self):
+        self.df.round()
+
+    def time_round_transposed(self):
+        self.df_t.round()
+
+    def peakmem_round(self):
+        self.df.round()
+
+    def peakmem_round_transposed(self):
+        self.df_t.round()
+
+
+class Where:
+    params = (
+        [True, False],
+        ["float64", "Float64", "float64[pyarrow]"],
+    )
+    param_names = ["dtype"]
+
+    def setup(self, inplace, dtype):
+        self.df = DataFrame(np.random.randn(100_000, 10), dtype=dtype)
+        self.mask = self.df < 0
+
+    def time_where(self, inplace, dtype):
+        self.df.where(self.mask, other=0.0, inplace=inplace)
+
+
+class FindValidIndex:
+    param_names = ["dtype"]
+    params = [
+        ["float", "Float64", "float64[pyarrow]"],
+    ]
+
+    def setup(self, dtype):
+        df = DataFrame(
+            np.random.randn(100000, 2),
+            columns=list("AB"),
+            dtype=dtype,
+        )
+        df.iloc[:100, 0] = None
+        df.iloc[:200, 1] = None
+        df.iloc[-100:, 0] = None
+        df.iloc[-200:, 1] = None
+        self.df = df
+
+    def time_first_valid_index(self, dtype):
+        self.df.first_valid_index()
+
+    def time_last_valid_index(self, dtype):
+        self.df.last_valid_index()
+
+
 from .pandas_vb_common import setup  # noqa: F401 isort:skip
