@@ -2,14 +2,12 @@ import numpy as np
 
 from pandas import (
     DataFrame,
+    Index,
     date_range,
     read_pickle,
 )
 
-from ..pandas_vb_common import (
-    BaseIO,
-    tm,
-)
+from ..pandas_vb_common import BaseIO
 
 
 class Pickle(BaseIO):
@@ -20,9 +18,9 @@ class Pickle(BaseIO):
         self.df = DataFrame(
             np.random.randn(N, C),
             columns=[f"float{i}" for i in range(C)],
-            index=date_range("20000101", periods=N, freq="H"),
+            index=date_range("20000101", periods=N, freq="h"),
         )
-        self.df["object"] = tm.makeStringIndex(N)
+        self.df["object"] = Index([f"i-{i}" for i in range(N)], dtype=object)
         self.df.to_pickle(self.fname)
 
     def time_read_pickle(self):
