@@ -7,7 +7,6 @@ from pandas import (
 
 
 class Render:
-
     params = [[12, 24, 36], [12, 120]]
     param_names = ["cols", "rows"]
 
@@ -67,7 +66,7 @@ class Render:
         self.st = self.df.style.apply(_apply_func, axis=1)
 
     def _style_classes(self):
-        classes = self.df.applymap(lambda v: ("cls-1" if v > 0 else ""))
+        classes = self.df.map(lambda v: ("cls-1" if v > 0 else ""))
         classes.index, classes.columns = self.df.index, self.df.columns
         self.st = self.df.style.set_td_classes(classes)
 
@@ -81,13 +80,13 @@ class Render:
         )
 
     def _style_apply_format_hide(self):
-        self.st = self.df.style.applymap(lambda v: "color: red;")
+        self.st = self.df.style.map(lambda v: "color: red;")
         self.st.format("{:.3f}")
-        self.st.hide_index(self.st.index[1:])
-        self.st.hide_columns(self.st.columns[1:])
+        self.st.hide(self.st.index[1:], axis=0)
+        self.st.hide(self.st.columns[1:], axis=1)
 
     def _style_tooltips(self):
         ttips = DataFrame("abc", index=self.df.index[::2], columns=self.df.columns[::2])
         self.st = self.df.style.set_tooltips(ttips)
-        self.st.hide_index(self.st.index[12:])
-        self.st.hide_columns(self.st.columns[12:])
+        self.st.hide(self.st.index[12:], axis=0)
+        self.st.hide(self.st.columns[12:], axis=1)
