@@ -17,7 +17,7 @@ for imp in ["pandas._libs.lib", "pandas.lib"]:
 try:
     import pandas._testing as tm
 except ImportError:
-    import pandas.util.testing as tm  # noqa:F401
+    import pandas.util.testing as tm  # noqa: F401
 
 
 numeric_dtypes = [
@@ -70,7 +70,7 @@ class BaseIO:
     def remove(self, f):
         """Remove created files"""
         try:
-            os.remove(f)  # noqa: PDF008
+            os.remove(f)
         except OSError:
             # On Windows, attempting to remove a file that is in use
             # causes an exception to be raised
