@@ -20,6 +20,39 @@ class FrameOps:
         self.df_func(axis=axis)
 
 
+class FrameMixedDtypesOps:
+    params = [ops, [0, 1, None]]
+    param_names = ["op", "axis"]
+
+    def setup(self, op, axis):
+        if op in ("sum", "skew", "kurt", "prod", "sem", "var") or (
+            (op, axis)
+            in (
+                ("mean", 1),
+                ("mean", None),
+                ("median", 1),
+                ("median", None),
+                ("std", 1),
+            )
+        ):
+            # Skipping cases where datetime aggregations are not implemented
+            raise NotImplementedError
+
+        N = 1_000_000
+        df = pd.DataFrame(
+            {
+                "f": np.random.normal(0.0, 1.0, N),
+                "i": np.random.randint(0, N, N),
+                "ts": pd.date_range(start="1/1/2000", periods=N, freq="h"),
+            }
+        )
+
+        self.df_func = getattr(df, op)
+
+    def time_op(self, op, axis):
+        self.df_func(axis=axis)
+
+
 class FrameMultiIndexOps:
     params = [ops]
     param_names = ["op"]
