@@ -27,11 +27,18 @@ from pandas.core.arrays.integer import (
     ]
 )
 def dtype(request):
+    """Parametrized fixture returning integer 'dtype'"""
     return request.param()
 
 
 @pytest.fixture
 def data(dtype):
+    """
+    Fixture returning 'data' array with valid and missing values according to
+    parametrized integer 'dtype'.
+
+    Used to test dtype conversion with and without missing values.
+    """
     return pd.array(
         list(range(8)) + [np.nan] + list(range(10, 98)) + [np.nan] + [99, 100],
         dtype=dtype,
@@ -40,12 +47,21 @@ def data(dtype):
 
 @pytest.fixture
 def data_missing(dtype):
+    """
+    Fixture returning array with exactly one NaN and one valid integer,
+    according to parametrized integer 'dtype'.
+
+    Used to test dtype conversion with and without missing values.
+    """
     return pd.array([np.nan, 1], dtype=dtype)
 
 
 @pytest.fixture(params=["data", "data_missing"])
 def all_data(request, data, data_missing):
-    """Parametrized fixture giving 'data' and 'data_missing'"""
+    """Parametrized fixture returning 'data' or 'data_missing' integer arrays.
+
+    Used to test dtype conversion with and without missing values.
+    """
     if request.param == "data":
         return data
     elif request.param == "data_missing":
