@@ -7,8 +7,6 @@ import itertools
 import numpy as np
 import pytest
 
-from pandas.compat import pa_version_under7p0
-
 from pandas.core.dtypes.cast import construct_1d_object_array_from_listlike
 
 import pandas as pd
@@ -203,15 +201,15 @@ def test_from_arrays_tuples(idx):
     [
         (
             pd.period_range("2011-01-01", freq="D", periods=3),
-            pd.period_range("2015-01-01", freq="H", periods=3),
+            pd.period_range("2015-01-01", freq="h", periods=3),
         ),
         (
             date_range("2015-01-01 10:00", freq="D", periods=3, tz="US/Eastern"),
-            date_range("2015-01-01 10:00", freq="H", periods=3, tz="Asia/Tokyo"),
+            date_range("2015-01-01 10:00", freq="h", periods=3, tz="Asia/Tokyo"),
         ),
         (
             pd.timedelta_range("1 days", freq="D", periods=3),
-            pd.timedelta_range("2 hours", freq="H", periods=3),
+            pd.timedelta_range("2 hours", freq="h", periods=3),
         ),
     ],
 )
@@ -229,7 +227,7 @@ def test_from_arrays_index_series_period_datetimetz_and_timedelta(idx1, idx2):
 
 def test_from_arrays_index_datetimelike_mixed():
     idx1 = date_range("2015-01-01 10:00", freq="D", periods=3, tz="US/Eastern")
-    idx2 = date_range("2015-01-01 10:00", freq="H", periods=3)
+    idx2 = date_range("2015-01-01 10:00", freq="h", periods=3)
     idx3 = pd.timedelta_range("1 days", freq="D", periods=3)
     idx4 = pd.period_range("2011-01-01", freq="D", periods=3)
 
@@ -648,10 +646,9 @@ def test_from_frame():
     tm.assert_index_equal(expected, result)
 
 
-@pytest.mark.skipif(pa_version_under7p0, reason="minimum pyarrow not installed")
 def test_from_frame_missing_values_multiIndex():
     # GH 39984
-    import pyarrow as pa
+    pa = pytest.importorskip("pyarrow")
 
     df = pd.DataFrame(
         {
@@ -778,7 +775,7 @@ def test_datetimeindex():
     idx1 = pd.DatetimeIndex(
         ["2013-04-01 9:00", "2013-04-02 9:00", "2013-04-03 9:00"] * 2, tz="Asia/Tokyo"
     )
-    idx2 = date_range("2010/01/01", periods=6, freq="M", tz="US/Eastern")
+    idx2 = date_range("2010/01/01", periods=6, freq="ME", tz="US/Eastern")
     idx = MultiIndex.from_arrays([idx1, idx2])
 
     expected1 = pd.DatetimeIndex(
@@ -850,11 +847,14 @@ def test_multiindex_inference_consistency():
     assert lev.dtype == object
 
 
-def test_dtype_representation():
+def test_dtype_representation(using_infer_string):
     # GH#46900
     pmidx = MultiIndex.from_arrays([[1], ["a"]], names=[("a", "b"), ("c", "d")])
     result = pmidx.dtypes
+    exp = "object" if not using_infer_string else pd.StringDtype(na_value=np.nan)
     expected = Series(
-        ["int64", "object"], index=MultiIndex.from_tuples([("a", "b"), ("c", "d")])
+        ["int64", exp],
+        index=MultiIndex.from_tuples([("a", "b"), ("c", "d")]),
+        dtype=object,
     )
     tm.assert_series_equal(result, expected)
