@@ -19,7 +19,7 @@ def test_multiindex_period_datetime():
 
     idx1 = Index(["a", "a", "a", "b", "b"])
     idx2 = period_range("2012-01", periods=len(idx1), freq="M")
-    s = Series(np.random.randn(len(idx1)), [idx1, idx2])
+    s = Series(np.random.default_rng(2).standard_normal(len(idx1)), [idx1, idx2])
 
     # try Period as index
     expected = s.iloc[0]
