@@ -4,13 +4,18 @@ import unicodedata
 import numpy as np
 import pytest
 
+import pandas.util._test_decorators as td
+
 from pandas.core.dtypes.common import is_integer_dtype
 
 import pandas as pd
 from pandas import (
+    ArrowDtype,
     Categorical,
+    CategoricalDtype,
     CategoricalIndex,
     DataFrame,
+    Index,
     RangeIndex,
     Series,
     SparseDtype,
@@ -19,6 +24,11 @@ from pandas import (
 import pandas._testing as tm
 from pandas.core.arrays.sparse import SparseArray
 
+try:
+    import pyarrow as pa
+except ImportError:
+    pa = None
+
 
 class TestGetDummies:
     @pytest.fixture
@@ -69,7 +79,7 @@ class TestGetDummies:
         result = get_dummies(s_series_index, sparse=sparse, dtype=dtype)
         tm.assert_frame_equal(result, expected)
 
-    def test_get_dummies_basic_types(self, sparse, dtype):
+    def test_get_dummies_basic_types(self, sparse, dtype, using_infer_string):
         # GH 10531
         s_list = list("abc")
         s_series = Series(s_list)
@@ -110,7 +120,8 @@ class TestGetDummies:
 
         result = get_dummies(s_df, columns=["a"], sparse=sparse, dtype=dtype)
 
-        expected_counts = {"int64": 1, "object": 1}
+        key = "str" if using_infer_string else "object"
+        expected_counts = {"int64": 1, key: 1}
         expected_counts[dtype_name] = 3 + expected_counts.get(dtype_name, 0)
 
         expected = Series(expected_counts, name="count").sort_index()
@@ -203,10 +214,10 @@ class TestGetDummies:
 
         tm.assert_frame_equal(result, expected)
 
-    def test_dataframe_dummies_string_dtype(self, df):
+    def test_dataframe_dummies_string_dtype(self, df, any_string_dtype):
         # GH44965
         df = df[["A", "B"]]
-        df = df.astype({"A": "object", "B": "string"})
+        df = df.astype({"A": "str", "B": any_string_dtype})
         result = get_dummies(df)
         expected = DataFrame(
             {
@@ -217,6 +228,8 @@ class TestGetDummies:
             },
             dtype=bool,
         )
+        if any_string_dtype == "string" and any_string_dtype.na_value is pd.NA:
+            expected[["B_b", "B_c"]] = expected[["B_b", "B_c"]].astype("boolean")
         tm.assert_frame_equal(result, expected)
 
     def test_dataframe_dummies_mix_default(self, df, sparse, dtype):
@@ -693,3 +706,35 @@ class TestGetDummies:
             dtype=any_numeric_ea_and_arrow_dtype,
         )
         tm.assert_frame_equal(result, expected)
+
+    @pytest.mark.parametrize("dtype_type", ["string", "category"])
+    def test_get_dummies_ea_dtype(self, dtype_type, string_dtype_no_object):
+        # GH#56273
+        dtype = string_dtype_no_object
+        exp_dtype = "boolean" if dtype.na_value is pd.NA else "bool"
+        if dtype_type == "category":
+            dtype = CategoricalDtype(Index(["a"], dtype))
+        df = DataFrame({"name": Series(["a"], dtype=dtype), "x": 1})
+        result = get_dummies(df)
+        expected = DataFrame({"x": 1, "name_a": Series([True], dtype=exp_dtype)})
+        tm.assert_frame_equal(result, expected)
+
+    @td.skip_if_no("pyarrow")
+    def test_get_dummies_arrow_dtype(self):
+        # GH#56273
+        df = DataFrame({"name": Series(["a"], dtype=ArrowDtype(pa.string())), "x": 1})
+        result = get_dummies(df)
+        expected = DataFrame({"x": 1, "name_a": Series([True], dtype="bool[pyarrow]")})
+        tm.assert_frame_equal(result, expected)
+
+        df = DataFrame(
+            {
+                "name": Series(
+                    ["a"],
+                    dtype=CategoricalDtype(Index(["a"], dtype=ArrowDtype(pa.string()))),
+                ),
+                "x": 1,
+            }
+        )
+        result = get_dummies(df)
+        tm.assert_frame_equal(result, expected)
