@@ -9,6 +9,7 @@ This is meant to be run as a pre-commit hook - to run it manually, you can do:
 
 The function `visit` is adapted from a function by the same name in pyupgrade:
 https://github.com/asottile/pyupgrade/blob/5495a248f2165941c5d3b82ac3226ba7ad1fa59d/pyupgrade/_data.py#L70-L113
+Licence at LICENSES/PYUPGRADE_LICENSE
 """
 from __future__ import annotations
 
@@ -64,7 +65,7 @@ def replace_bool_with_bool_t(to_replace, content: str) -> str:
                     + replaced_line[col_offset + 4 :]
                 )
         new_lines.append(replaced_line)
-    return "\n".join(new_lines)
+    return "\n".join(new_lines) + "\n"
 
 
 def check_for_bool_in_generic(content: str) -> tuple[bool, str]:
